pub struct FilePruner { /* private fields */ }Expand description
Prune based on file-level statistics.
Note: Partition column pruning is handled earlier via replace_columns_with_literals
which substitutes partition column references with their literal values before
the predicate reaches this pruner.
Implementations
Sourceimpl FilePruner
impl FilePruner
pub fn new( predicate: Arc<dyn PhysicalExpr>, logical_file_schema: &SchemaRef, _partition_fields: Vec<FieldRef>, partitioned_file: PartitionedFile, predicate_creation_errors: Count, ) -> Result<Self>
👎Deprecated since 52.0.0: Use
try_new instead which returns None if no statistics are availableSourcepub fn try_new(
predicate: Arc<dyn PhysicalExpr>,
file_schema: &SchemaRef,
partitioned_file: &PartitionedFile,
predicate_creation_errors: Count,
) -> Option<Self>
pub fn try_new( predicate: Arc<dyn PhysicalExpr>, file_schema: &SchemaRef, partitioned_file: &PartitionedFile, predicate_creation_errors: Count, ) -> Option<Self>
Create a new file pruner if statistics are available. Returns None if this file does not have statistics.
pub fn should_prune(&mut self) -> Result<bool>