pub trait UnhandledPredicateHook {
// Required method
fn handle(&self, expr: &Arc<dyn PhysicalExpr>) -> Arc<dyn PhysicalExpr> ⓘ;
}Expand description
Rewrites predicates that PredicateRewriter can not handle, e.g. certain
complex expressions or predicates that reference columns that are not in the
schema.
Required Methods
Sourcefn handle(&self, expr: &Arc<dyn PhysicalExpr>) -> Arc<dyn PhysicalExpr> ⓘ
fn handle(&self, expr: &Arc<dyn PhysicalExpr>) -> Arc<dyn PhysicalExpr> ⓘ
Called when a predicate can not be rewritten in terms of statistics or references a column that is not in the schema.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".